pygeodesy.auxilats.auxDLat.AuxDLat

Package pygeodesy :: Package auxilats :: Module auxDLat :: Class AuxDLat |
[frames] | no frames]

# Class AuxDLat

       object --+
                |
     named._Named --+
                    |
    auxAngle.AuxAngle --+
                        |
            auxLat.AuxLat --+
                            |
                           AuxDLat

Class to compute `Divided Differences` of Auxiliary latitudes and other `Divided Differences` needed for RhumbAux and RhumbLineAux calculations.

Instance Methods
CParametric(self, Zeta1, Zeta2) Short for `.Dconvert(Aux.BETA, Zeta1, Zeta2)`. |
CRectifying(self, Zeta1, Zeta2) Short for `.Dconvert(Aux.MU, Zeta1, Zeta2)`. |
Dconvert(self, auxout, Zeta1, Zeta2) Divided Difference of one auxiliary latitude wrt another. |
DE(self, X, Y) |
DIsometric(self, Phi1, Phi2) Divided Difference of the isometric wrt the geographic latitude. |
DParametric(self, Phi1, Phi2) Divided Difference of the parametric wrt the geographic latitude. |
DRectifying(self, Phi1, Phi2) Divided Difference of the rectifying wrt the geographic latitude. |
Inherited from `auxLat.AuxLat`: `Authalic`, `AuthalicRadius2`, `Conformal`, `Geocentric`, `Geodetic`, `Parametric`, `Rectifying`, `RectifyingRadius`, `Reduced`, `__init__`, `convert` Inherited from `auxAngle.AuxAngle`: `__abs__`, `__add__`, `__bool__`, `__eq__`, `__float__`, `__iadd__`, `__isub__`, `__ne__`, `__neg__`, `__pos__`, `__radd__`, `__rsub__`, `__str__`, `__sub__`, `copyquadrant`, `normal`, `toBeta`, `toChi`, `toMu`, `toPhi` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `auxAngle.AuxAngle`: `fromDegrees`, `fromLambertianDegrees`, `fromLambertianRadians`, `fromRadians`

Properties
Inherited from `auxLat.AuxLat`: `ALorder`, `a`, `b`, `ellipsoid`, `equatoradius`, `f`, `flattening`, `polaradius` Inherited from `auxAngle.AuxAngle`: `diff`, `iteration`, `normalized`, `tan`, `toDegrees`, `toLambertianDegrees`, `toLambertianRadians`, `toRadians`, `x`, `y` Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`